==> thousandeyes_sdk_event_detection-1.3.0.tar.gz: thousandeyes_sdk_event_detection-1.3.0/docs/ProxyEventDetail.md <==
# ProxyEventDetail


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** | A unique ID for each event. | [optional] [readonly] 
**type_name** | **str** | Event type name. Examples include, Local Agent Issue, Network Path Issue, Network Outage, DNS Issue, Server Issue, and Proxy Issue. | [optional] [readonly] 
**state** | [**EventState**](EventState.md) |  | [optional] 
**start_date** | **datetime** | The start date and time (in UTC, ISO 8601 format) when the event was first detected. | [optional] [readonly] 
**end_date** | **datetime** | The end date and time (in UTC, ISO 8601 format) when the event was resolved (due to timeout). This value is populated for \&quot;ongoing\&quot; events. | [optional] [readonly] 
**severity** | [**Severity**](Severity.md) |  | [optional] 
**aid** | **str** | A unique identifier associated with your account group. You can retrieve your &#x60;AccountGroupId&#x60; from the &#x60;/account-groups&#x60; endpoint. | [optional] 
**summary** | **str** | A brief summary describing the cause of the event. | [optional] [readonly] 
**affected_tests** | [**AffectedTests**](AffectedTests.md) |  | [optional] 
**affected_targets** | [**AffectedTargets**](AffectedTargets.md) |  | [optional] 
**affected_agents** | [**AffectedAgents**](AffectedAgents.md) |  | [optional] 
**cause** | **List[str]** | The cause of the error. | [optional] 
**links** | [**SelfLinks**](SelfLinks.md) |  | [optional] 
**type** | **str** | Proxy event type. | 
**grouping** | [**ProxyEventGrouping**](ProxyEventGrouping.md) |  | [optional] 

## Example

```python
from thousandeyes_sdk.event_detection.models.proxy_event_detail import ProxyEventDetail

# TODO update the JSON string below
json = "{}"
# create an instance of ProxyEventDetail from a JSON string
proxy_event_detail_instance = ProxyEventDetail.from_json(json)
# print the JSON string representation of the object
print(ProxyEventDetail.to_json())

# convert the object into a dict
proxy_event_detail_dict = proxy_event_detail_instance.to_dict()
# create an instance of ProxyEventDetail from a dict
proxy_event_detail_from_dict = ProxyEventDetail.from_dict(proxy_event_detail_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

==> thousandeyes_sdk_event_detection-2.0.1.tar.gz: thousandeyes_sdk_event_detection-2.0.1/docs/ProxyEventDetail.md <==
# ProxyEventDetail


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** | A unique ID for each event. | [optional] [readonly] 
**type_name** | **str** | Event type name. Examples include, Local Agent Issue, Network Path Issue, Network Outage, DNS Issue, Server Issue, and Proxy Issue. | [optional] [readonly] 
**state** | [**EventState**](EventState.md) |  | [optional] 
**start_date** | **datetime** | The start date and time (in UTC, ISO 8601 format) when the event was first detected. | [optional] [readonly] 
**end_date** | **datetime** | The end date and time (in UTC, ISO 8601 format) when the event was resolved (due to timeout). This value is populated for \&quot;ongoing\&quot; events. | [optional] [readonly] 
**severity** | [**EventAlertSeverity**](EventAlertSeverity.md) |  | [optional] 
**aid** | **str** | A unique identifier associated with your account group. You can retrieve your &#x60;AccountGroupId&#x60; from the &#x60;/account-groups&#x60; endpoint. | [optional] 
**summary** | **str** | A brief summary describing the cause of the event. | [optional] [readonly] 
**affected_tests** | [**AffectedTests**](AffectedTests.md) |  | [optional] 
**affected_targets** | [**AffectedTargets**](AffectedTargets.md) |  | [optional] 
**affected_agents** | [**AffectedAgents**](AffectedAgents.md) |  | [optional] 
**cause** | **List[str]** | The cause of the error. | [optional] 
**links** | [**SelfLinks**](SelfLinks.md) |  | [optional] 
**type** | **str** | Proxy event type. | 
**grouping** | [**ProxyEventGrouping**](ProxyEventGrouping.md) |  | [optional] 

## Example

```python
from thousandeyes_sdk.event_detection.models.proxy_event_detail import ProxyEventDetail

# TODO update the JSON string below
json = "{}"
# create an instance of ProxyEventDetail from a JSON string
proxy_event_detail_instance = ProxyEventDetail.from_json(json)
# print the JSON string representation of the object
print(ProxyEventDetail.to_json())

# convert the object into a dict
proxy_event_detail_dict = proxy_event_detail_instance.to_dict()
# create an instance of ProxyEventDetail from a dict
proxy_event_detail_from_dict = ProxyEventDetail.from_dict(proxy_event_detail_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)
